"use strict";
var BackButtonMiddleware_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackButtonMiddleware = void 0;
const tslib_1 = require("tslib");
const types_1 = require("./types");
const logger_1 = require("../../logger");
const __1 = require("../..");
/**
 * Middleware для добавления кнопки назад в inline клавиатуру
 */
let BackButtonMiddleware = BackButtonMiddleware_1 = class BackButtonMiddleware extends types_1.BaseMiddleware {
    constructor() {
        super(...arguments);
        this.logger = new logger_1.Logger('BackButtonMiddleware', { logLevel: logger_1.LogLevel.DEBUG });
        this.priority = 3;
    }
    before(_a, next_1) {
        return tslib_1.__awaiter(this, arguments, void 0, function* ({ params, method, state }, next) {
            var _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
            if (!BackButtonMiddleware_1.ALLOWED_METHODS.includes(method))
                return next();
            if (!params.chat_id || params.noBackButton || ((_b = params.reply_markup) === null || _b === void 0 ? void 0 : _b.keyboard))
                return next();
            if ((_d = (_c = params.reply_markup) === null || _c === void 0 ? void 0 : _c.inline_keyboard) === null || _d === void 0 ? void 0 : _d.find((x) => x.find((y) => y.isBackButton)))
                return this.logger.debug('Skipping back button middleware, because inline keyboard already has back button'), next();
            const message = yield this.client.database.message.getMessage(params.chat_id, params.message_id);
            if (!message)
                return this.logger.debug('Skipping back button middleware, because message is not found'), next();
            let history = message.history;
            // Обработка, если данная кнопка является кнопкой назад
            if ((_e = state.callbackData) === null || _e === void 0 ? void 0 : _e.isBackButton) {
                // Получаем команду, которая была вызвана кнопкой назад
                const activeCommand = __1.CommandManager.commands.find((x) => { var _a; return [x === null || x === void 0 ? void 0 : x.params.name, x === null || x === void 0 ? void 0 : x.name].includes((_a = state.callbackData) === null || _a === void 0 ? void 0 : _a.command); });
                // Если команда найдена, то удаляем все команды после нее
                // prettier-ignore
                if (activeCommand)
                    history = history.slice(0, history.findIndex((x) => x.command === activeCommand.params.name));
            }
            if (((_f = history.at(-1)) === null || _f === void 0 ? void 0 : _f.command) === ((_h = (_g = state === null || state === void 0 ? void 0 : state.command) === null || _g === void 0 ? void 0 : _g.params) === null || _h === void 0 ? void 0 : _h.name))
                history.pop();
            if (!(history === null || history === void 0 ? void 0 : history.length))
                return this.logger.debug('Skipping back button middleware, because history is empty or has only one command'), next();
            history.reverse();
            const lastCommand = history.find((x) => __1.CommandManager.commands.find((y) => { var _a, _b; return ((_a = y.params) === null || _a === void 0 ? void 0 : _a.name) === x.command && ((_b = y.params) === null || _b === void 0 ? void 0 : _b.backButton); }));
            const backButtonText = (_k = (_j = __1.CommandManager.commands.find((x) => { var _a; return ((_a = x.params) === null || _a === void 0 ? void 0 : _a.name) === (lastCommand === null || lastCommand === void 0 ? void 0 : lastCommand.command); })) === null || _j === void 0 ? void 0 : _j.params) === null || _k === void 0 ? void 0 : _k.backButton;
            if (!backButtonText)
                return this.logger.debug('Skipping back button middleware, because backButtonText is not set'), next();
            // prettier-ignore
            const backButton = [{ text: `‹ ${backButtonText}`, command: lastCommand === null || lastCommand === void 0 ? void 0 : lastCommand.command, payload: (lastCommand === null || lastCommand === void 0 ? void 0 : lastCommand.arguments) || {}, isBackButton: true }];
            this.logger.log(`Message nav history: ${history.map((x) => x.command).join(' -> ')}`);
            if ((params === null || params === void 0 ? void 0 : params.reply_markup) && ((_l = params === null || params === void 0 ? void 0 : params.reply_markup) === null || _l === void 0 ? void 0 : _l.inline_keyboard))
                (_m = params === null || params === void 0 ? void 0 : params.reply_markup) === null || _m === void 0 ? void 0 : _m.inline_keyboard.push(backButton);
            else if (params)
                params.reply_markup = { inline_keyboard: [backButton] };
            return next();
        });
    }
};
exports.BackButtonMiddleware = BackButtonMiddleware;
BackButtonMiddleware.ALLOWED_METHODS = ['editMessageText', 'editMessageCaption', 'editMessageMedia', 'editMessageReplyMarkup'];
exports.BackButtonMiddleware = BackButtonMiddleware = BackButtonMiddleware_1 = tslib_1.__decorate([
    (0, types_1.ApiMiddleware)()
], BackButtonMiddleware);
