"use strict";
var CommandsHistoryMiddleware_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandsHistoryMiddleware = void 0;
const tslib_1 = require("tslib");
const types_1 = require("./types");
const logger_1 = require("../../logger");
const Logger_1 = require("../../logger/Logger");
let CommandsHistoryMiddleware = CommandsHistoryMiddleware_1 = class CommandsHistoryMiddleware extends types_1.BaseMiddleware {
    constructor() {
        super(...arguments);
        this.logger = new logger_1.Logger('CommandsHistoryMiddleware', { logLevel: Logger_1.LogLevel.DEBUG });
        this.priority = 2;
    }
    after(_a) {
        return tslib_1.__awaiter(this, arguments, void 0, function* ({ params, method, state, result }) {
            var _b, _c;
            if (!CommandsHistoryMiddleware_1.ALLOWED_METHODS.includes(method) || !result.message_id)
                return this.logger.debug(`Skipping commands history middleware, because method is not allowed or message_id is not set (${method})`);
            if (!state.command)
                return this.logger.debug('Skipping commands history middleware, because command not found');
            const message = yield this.client.database.message.getMessage(params.chat_id, result.message_id);
            if (!message)
                return this.logger.debug(`Skipping commands history middleware, because message is not found (id: ${result.message_id}, chat_id: ${params.chat_id})`);
            if (!((_b = state.callbackData) === null || _b === void 0 ? void 0 : _b.isBackButton)) {
                const lastMessage = message.history.at(-1);
                if (lastMessage && (lastMessage === null || lastMessage === void 0 ? void 0 : lastMessage.command) === ((_c = state.command) === null || _c === void 0 ? void 0 : _c.params.name)) {
                    lastMessage.arguments = state.commandArguments;
                    lastMessage.chat_id = params.chat_id;
                }
                else {
                    message.history.push({
                        command: state.command.params.name,
                        arguments: state.commandArguments,
                        chat_id: params.chat_id,
                    });
                }
            }
            else {
                message.history.pop();
            }
            //@ts-ignore
            this.client.database.message.updateMessage(message.message_id, { history: message.history });
        });
    }
};
exports.CommandsHistoryMiddleware = CommandsHistoryMiddleware;
CommandsHistoryMiddleware.ALLOWED_METHODS = [
    'sendMessage',
    'editMessageText',
    'editMessageCaption',
    'editMessageMedia',
    'editMessageReplyMarkup',
    'sendPhoto',
    'sendAudio',
    'sendDocument',
    'sendVideo',
    'sendAnimation',
    'sendVideoNote',
    'sendVoice',
    'sendLocation',
    'sendVenue',
];
exports.CommandsHistoryMiddleware = CommandsHistoryMiddleware = CommandsHistoryMiddleware_1 = tslib_1.__decorate([
    (0, types_1.ApiMiddleware)()
], CommandsHistoryMiddleware);
