"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiddlewareManager = void 0;
const tslib_1 = require("tslib");
class MiddlewareManager {
    constructor(client) {
        this.client = client;
        this.middlewares = [];
        //@ts-ignore
        this.middlewares = MiddlewareManager.middlewares.map((M) => new M(client)).sort((a, b) => a.priority - b.priority);
    }
    use(middleware) {
        this.middlewares.push(middleware);
        this.middlewares.sort((a, b) => a.priority - b.priority);
    }
    createNextFunction(middlewares, ctx, index) {
        return () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (index < middlewares.length) {
                const middleware = middlewares[index];
                yield middleware.execute(ctx, this.createNextFunction(middlewares, ctx, index + 1));
            }
        });
    }
    executeBefore(ctx) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let allNextCalled = true;
            const middlewares = this.middlewares.sort((a, b) => a.priority - b.priority).filter((x) => x.before);
            // Recursive function to run middleware in order
            const run = (index) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                var _a;
                if (index >= middlewares.length)
                    return;
                const middleware = middlewares[index];
                let nextCalled = false;
                try {
                    // Call the current middleware, providing context and the next function
                    yield ((_a = middleware === null || middleware === void 0 ? void 0 : middleware.before) === null || _a === void 0 ? void 0 : _a.call(middleware, ctx, () => tslib_1.__awaiter(this, void 0, void 0, function* () {
                        nextCalled = true;
                        yield run(index + 1); // Run the next middleware
                    })));
                }
                catch (error) {
                    console.error(`Error in middleware at index ${index}:`, error);
                    allNextCalled = false; // Middleware execution not fully successful
                }
                // Check if 'next' was called in this middleware
                if (!nextCalled)
                    allNextCalled = false; // If 'next' wasn't called, mark as incomplete
            });
            // Start running from the first middleware
            yield run(0);
            return allNextCalled ? ctx.params : null; // Return context if all middlewares executed successfully
        });
    }
    executeAfter(ctx) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            for (const middleware of this.middlewares.sort((a, b) => a.priority - b.priority))
                if (middleware.after)
                    yield middleware.after(ctx);
        });
    }
    executeError(ctx, error) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            for (const middleware of this.middlewares.sort((a, b) => a.priority - b.priority))
                if (middleware.error)
                    yield middleware.error(ctx, error);
        });
    }
}
exports.MiddlewareManager = MiddlewareManager;
MiddlewareManager.middlewares = [];
