"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Evogram = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const API_1 = require("./API");
const database_1 = require("./database");
const middleware_1 = require("./middleware");
const question_1 = require("./question");
const updates_1 = require("./updates");
const commands_1 = require("./commands");
const logger_1 = require("./logger");
/** Represents the main client for the Evogram framework. */
class Evogram {
    /**
     * Creates an instance of the Evogram client.
     * @param token - The bot token used for authentication with the Telegram Bot API.
     * @throws {Error} Throws an error if the token is invalid.
     */
    constructor(params) {
        this.params = params;
        this.logger = new logger_1.Logger();
        this.directory = path_1.default.join(process.cwd(), '.evogram', this.params.token.split(':')[0] || 'default');
        this.api = new API_1.API(this);
        this.middleware = new middleware_1.Middleware();
        this.updates = new updates_1.Updates(this);
        this.database = new database_1.DatabaseManager(this);
        this.question = new question_1.QuestionManager();
        this.commands = new commands_1.CommandManager(this);
        if (!Evogram.TOKEN_REGEX.test(this.params.token))
            throw new Error('Invalid bot token format.');
    }
    init() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.database.init();
            this.bot = yield this.api.getMe();
            this.logger.log(`Initialized bot: ${this.bot.username} (${this.bot.id})`);
        });
    }
    clone() {
        return Object.assign(Object.assign({}, this), { api: Object.assign({}, this.api) });
    }
}
exports.Evogram = Evogram;
Evogram.TOKEN_REGEX = /^[0-9]+:[a-zA-Z0-9_-]+$/;
