"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Command = void 0;
const tslib_1 = require("tslib");
//@ts-check
const __1 = require("..");
const logger_1 = require("../logger");
const migrated_1 = require("../migrated");
// Утилита для получения метаданных с учётом наследования
function getInheritedMetadata(target, propertyKey) {
    let prototype = target;
    // Список для сбора метаданных
    const allMetadata = [];
    while (prototype) {
        const metadata = Reflect.getOwnMetadata('custom:arguments', prototype, propertyKey);
        if (metadata) {
            allMetadata.unshift(...metadata); // Добавляем метаданные, найденные выше в цепочке наследования
        }
        prototype = Object.getPrototypeOf(prototype); // Переходим к родительскому классу
    }
    return allMetadata;
}
class Command {
    get params() {
        //@ts-ignore
        return this.constructor.params;
    }
    constructor(client) {
        this.client = client;
        this.logger = new logger_1.Logger(this.constructor.name);
    }
    /**
     * Checks if a command is executable based on an incoming message.
     * @param message - The incoming message.
     */
    isExecutable(context) {
        var _a, _b;
        if (this.params.onlyFromKeyboard && !context.callbackQuery)
            return false;
        if (this.params.accessLevel && context.user.userDB.accessLevel < this.params.accessLevel)
            return false;
        for (const item of [this.params.name, this.constructor.name])
            if ((_b = (_a = context.callbackQuery) === null || _a === void 0 ? void 0 : _a.source.data) === null || _b === void 0 ? void 0 : _b.startsWith(`cdm ${item};`))
                return true;
        if (context.text) {
            const text = context.text.replace(`@${context.client.bot.username}`, '');
            for (const item of [`/${this.params.name}`, `/${this.params.name}`, ...(this.params.aliases || [])])
                if (typeof item === 'string'
                    ? text.replace(/\n/g, ' ').split(' ')[0].toLowerCase() === item.toLowerCase()
                    : item.test(text.replace(/\n/g, ' ')))
                    return true;
        }
        return false;
    }
    howUse(context) { }
    preExecute(context, args) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let command;
            try {
                if (this.client.question.priority === 'question' && this.client.question.getQuestion(context.user.id, false))
                    return;
                if (args)
                    context.state.callbackData = Object.assign(Object.assign({}, context.state.callbackData), { payload: args });
                //@ts-ignore
                command = migrated_1.CommandManager.commands.find((y) => { var _a; return ((_a = y.params) === null || _a === void 0 ? void 0 : _a.name) === this.params.name; });
                const resultArguments = yield (0, __1.getCommandArguments)(context, this);
                if (!resultArguments)
                    return yield this.howUse(context);
                context.state.commandArguments = resultArguments.resultArguments;
                const sortedArgs = this.arguments.sort((a, b) => a.index - b.index);
                yield this.execute(context, ...sortedArgs.map((arg) => resultArguments.validateArgs[arg.name]));
            }
            catch (error) {
                this.onError(context, error);
            }
        });
    }
    inlinePreExecute(context, args) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (args)
                context.state.callbackData = { payload: args };
            const resultArguments = yield (0, __1.getCommandArguments)(context, this);
            if (!resultArguments)
                return;
            const sortedArgs = this.inlineArguments.sort((a, b) => a.index - b.index);
            return yield this.inlineExecute(context, ...sortedArgs.map((arg) => resultArguments.validateArgs[arg.name]));
        });
    }
    inlineExecute(context, ...args) { }
    onError(context, error) {
        Command.onError(context, error);
    }
    static onError(context, error) {
        throw error;
    }
    get arguments() {
        //@ts-ignore
        return getInheritedMetadata(this, 'execute').sort((a, b) => a.index - b.index);
    }
    get inlineArguments() {
        //@ts-ignore
        return getInheritedMetadata(this, 'inlineExecute').sort((a, b) => a.index - b.index);
    }
}
exports.Command = Command;
Command.params = {};
