"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandArgument = CommandArgument;
require("reflect-metadata");
function CommandArgument(nameOrOptions, ...validators) {
    return function (target, propertyKey, parameterIndex) {
        // Получаем метаданные о типах аргументов
        const paramTypes = Reflect.getMetadata('design:paramtypes', target, propertyKey);
        if (!paramTypes) {
            console.error('paramTypes is undefined. Проверь tsconfig.json и импорт reflect-metadata.');
            return;
        }
        // Сохраняем данные об аргументах
        const existingArguments = Reflect.getOwnMetadata('custom:arguments', target, propertyKey) || [];
        existingArguments.push({
            index: parameterIndex,
            name: (typeof nameOrOptions === 'string' ? nameOrOptions : nameOrOptions.name).replace('?', ''),
            type: paramTypes[parameterIndex], // Тип аргумента
            validators: validators,
            isOptional: (typeof nameOrOptions === 'string' ? nameOrOptions : nameOrOptions.name).endsWith('?'),
            question: (typeof nameOrOptions === 'string' ? undefined : nameOrOptions.question) || undefined,
            askAgain: (typeof nameOrOptions === 'string' ? false : nameOrOptions.askAgain) || false,
        });
        Reflect.defineMetadata('custom:arguments', existingArguments, target, propertyKey);
    };
}
