"use strict";
var _Context_client, _Context_source, _Context_state, _Context_stateProxy;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = void 0;
const tslib_1 = require("tslib");
const ContextManager_1 = require("./ContextManager");
/**
 * The `Context` class is a generic container that holds contextual data related to a particular client, source, and state.
 *
 * @template T - The type of the source data that the context wraps.
 */
class Context {
    /**
     * Constructs a new `Context` instance.
     *
     * @param client - The `Evogram` client associated with this context.
     * @param source - The source data wrapped by this context.
     * @param state - Additional state information related to the context.
     */
    constructor({ client, source, state }) {
        // Private fields to store client, source, and state data
        _Context_client.set(this, void 0); // Holds the client instance (of type `Evogram`)
        _Context_source.set(this, void 0); // Holds the source data of generic type `T`
        _Context_state.set(this, void 0); // Holds additional state data
        _Context_stateProxy.set(this, null); // Приватное поле для прокси
        // Initialize the private fields with the provided parameters
        tslib_1.__classPrivateFieldSet(this, _Context_client, client, "f");
        tslib_1.__classPrivateFieldSet(this, _Context_source, source, "f");
        tslib_1.__classPrivateFieldSet(this, _Context_state, state || {}, "f");
    }
    /**
     * Gets the client associated with this context.
     *
     * @returns The `Evogram` client.
     */
    get client() {
        return tslib_1.__classPrivateFieldGet(this, _Context_client, "f");
    }
    /**
     * Gets the source data wrapped by this context.
     *
     * @returns The source data of type `T`.
     */
    get source() {
        return tslib_1.__classPrivateFieldGet(this, _Context_source, "f");
    }
    /**
     * Gets the state associated with this context.
     *
     * @returns The state data, which could be of any type (unknown).
     */
    get state() {
        if (!tslib_1.__classPrivateFieldGet(this, _Context_stateProxy, "f") && typeof tslib_1.__classPrivateFieldGet(this, _Context_state, "f") === 'object' && tslib_1.__classPrivateFieldGet(this, _Context_state, "f") !== null) {
            const handler = {
                set: (target, prop, value) => {
                    target[prop] = value;
                    tslib_1.__classPrivateFieldGet(this, _Context_client, "f").api.state[prop] = value;
                    return true;
                },
            };
            tslib_1.__classPrivateFieldSet(this, _Context_stateProxy, new Proxy(tslib_1.__classPrivateFieldGet(this, _Context_state, "f"), handler), "f");
        }
        return tslib_1.__classPrivateFieldGet(this, _Context_stateProxy, "f") || tslib_1.__classPrivateFieldGet(this, _Context_state, "f");
    }
    getContext(params) {
        return ContextManager_1.ContextManager.getContext(params.key, Object.assign(Object.assign({ client: tslib_1.__classPrivateFieldGet(this, _Context_client, "f") }, params), { state: Object.assign(tslib_1.__classPrivateFieldGet(this, _Context_state, "f") || {}, params.state) }));
    }
}
exports.Context = Context;
_Context_client = new WeakMap(), _Context_source = new WeakMap(), _Context_state = new WeakMap(), _Context_stateProxy = new WeakMap();
