import { TelegramBotCommand, TelegramDeleteMyCommandsParams, TelegramGetChatMenuButtonParams, TelegramGetMyCommandsParams, TelegramGetMyDefaultAdministratorRightsParams, TelegramSetChatMenuButtonParams, TelegramSetMyCommandsParams, TelegramSetMyDefaultAdministratorRightsParams } from '../../../types';
import { UserContext } from '../../../migrated';
export declare class BotContext extends UserContext {
    /** Indicates whether the user can join groups. */
    canJoinGroups: boolean | undefined;
    /** Indicates whether the user can read all group messages.*/
    canReadAllGroupMessages: boolean | undefined;
    /** * Indicates whether the user supports inline queries. */
    supportsInlineQueries: boolean | undefined;
    /** * Indicates whether the user can connect to business accounts. */
    canConnectToBusiness: boolean | undefined;
    /** * Indicates whether the user has access to the main web app. */
    hasMainWebapp: true | undefined;
    /**
     * Retrieves the current list of the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the current list of the bot's commands.
     */
    getCommands(params?: TelegramGetMyCommandsParams): Promise<TelegramBotCommand[]>;
    /**
     * Sets the bot's commands.
     * @param commands An array of IBotCommand objects representing the new list of the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setCommands(commands: TelegramBotCommand[], params?: Partial<TelegramSetMyCommandsParams>): Promise<true>;
    /**
     * Sets the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setCommands(params: TelegramSetMyCommandsParams): Promise<true>;
    /**
     * Deletes the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    deleteCommands(params?: TelegramDeleteMyCommandsParams): Promise<any>;
    /**
     * Sets the bot's menu button for a chat.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setChatMenuButton(params?: TelegramSetChatMenuButtonParams): Promise<boolean>;
    /**
     * Retrieves the bot's menu button for a chat.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the bot's menu button for the specified chat.
     */
    getChatMenuButton(params?: TelegramGetChatMenuButtonParams): Promise<import("../../../types").TelegramMenuButton>;
    /**
     * Sets the bot's default administrator rights.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setDefaultAdministratorRights(params?: TelegramSetMyDefaultAdministratorRightsParams): Promise<boolean>;
    /**
     * Retrieves the bot's default administrator rights.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the bot's default administrator rights.
     */
    getDefaultAdministratorRights(params?: TelegramGetMyDefaultAdministratorRightsParams): Promise<import("../../../types").TelegramChatAdministratorRights>;
}
