"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BotContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
const migrated_1 = require("../../../migrated");
let BotContext = class BotContext extends migrated_1.UserContext {
    constructor() {
        super(...arguments);
        /** Indicates whether the user can join groups. */
        this.canJoinGroups = this.source.can_join_groups;
        /** Indicates whether the user can read all group messages.*/
        this.canReadAllGroupMessages = this.source.can_read_all_group_messages;
        /** * Indicates whether the user supports inline queries. */
        this.supportsInlineQueries = this.source.supports_inline_queries;
        /** * Indicates whether the user can connect to business accounts. */
        this.canConnectToBusiness = this.source.can_connect_to_business;
        /** * Indicates whether the user has access to the main web app. */
        this.hasMainWebapp = this.source.has_main_web_app;
    }
    /**
     * Retrieves the current list of the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the current list of the bot's commands.
     */
    getCommands(params) {
        return this.client.api.getMyCommands(params);
    }
    setCommands(commands, params) {
        if (params && !params.commands)
            params.commands = commands;
        else if (!params)
            params = { commands };
        return this.client.api.setMyCommands(params);
    }
    /**
     * Deletes the bot's commands.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    deleteCommands(params) {
        return this.client.api.deleteMyCommands(params);
    }
    /**
     * Sets the bot's menu button for a chat.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setChatMenuButton(params) {
        return this.client.api.setChatMenuButton(params);
    }
    /**
     * Retrieves the bot's menu button for a chat.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the bot's menu button for the specified chat.
     */
    getChatMenuButton(params) {
        return this.client.api.getChatMenuButton(params);
    }
    /**
     * Sets the bot's default administrator rights.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to true if the operation succeeded.
     */
    setDefaultAdministratorRights(params) {
        return this.client.api.setMyDefaultAdministratorRights(params);
    }
    /**
     * Retrieves the bot's default administrator rights.
     * @param params Optional parameters to customize the behavior of the method.
     * @returns A Promise that resolves to the bot's default administrator rights.
     */
    getDefaultAdministratorRights(params) {
        return this.client.api.getMyDefaultAdministratorRights(params);
    }
};
exports.BotContext = BotContext;
exports.BotContext = BotContext = tslib_1.__decorate([
    (0, core_1.ContextD)('Bot')
], BotContext);
