import { TelegramMessageEntity } from '../../../types';
import { ChatContext, MessageOriginContext, UserContext } from '../../../migrated';
import { MessageAttachments } from './MessageAttachments';
import { MessageMethods } from './MessageMethods';
import { ReplyContext } from './MessageReply.context';
import { MessageUpdate } from './MessageUpdates';
export declare class MessageContext extends MessageMethods {
    /** The ID of the message. */
    id: number;
    /** The text of the message or its caption, if available. */
    text: string | undefined;
    /** The signature of the message author, if provided. */
    signature: string | undefined;
    /** The timestamp of when the message was sent (Unix time). */
    date: number;
    /** The timestamp of when the message was last edited, if available (Unix time). */
    editDate: number | undefined;
    /** The ID of the message thread, if this message is part of a thread. */
    messageThreadID: number | undefined;
    /** The ID of the business connection, if present. */
    businessConnectionID: string | undefined;
    /** Indicates if this message is part of a topic. */
    isTopicMessage: boolean | undefined;
    /** Indicates if the message has protected content. */
    hasProtectedContent: boolean | undefined;
    /** The ID of the special effect applied to this message, if any. */
    effectID: string | undefined;
    /** Indicates if this message is an automatic forward. */
    isAutomaticForward: boolean | undefined;
    /** Indicates if the message was sent from offline mode. */
    isFromOffline: boolean | undefined;
    /** The user who sent the message. */
    user: UserContext;
    /** The bot that forwarded the message, if any. */
    viaBot: UserContext | undefined;
    /** The chat where the message was sent. */
    chat: ChatContext;
    /** The chat that forwarded the message, if different from the sender. */
    senderChat: ChatContext | undefined;
    /** The message to which this message is a reply. */
    replyMessage: ReplyContext;
    /** The origin of the forwarded message, if applicable. */
    forwardMessage: MessageOriginContext | undefined;
    /** The entities (like mentions, hashtags) present in the message. */
    entities: TelegramMessageEntity[] | undefined;
    /** The reply markup (e.g., inline keyboard) associated with the message. */
    replyMarkup: import("../../../types").TelegramInlineKeyboardMarkup | undefined;
    /** The updates related to this message. */
    updates: MessageUpdate;
    /** The attachments (like photos, videos) present in the message. */
    attachments: MessageAttachments;
}
