"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
const MessageAttachments_1 = require("./MessageAttachments");
const MessageMethods_1 = require("./MessageMethods");
const MessageReply_context_1 = require("./MessageReply.context");
const MessageUpdates_1 = require("./MessageUpdates");
let MessageContext = class MessageContext extends MessageMethods_1.MessageMethods {
    constructor() {
        var _a;
        super(...arguments);
        /** The ID of the message. */
        this.id = this.source.message_id;
        /** The text of the message or its caption, if available. */
        this.text = this.source.text || this.source.caption;
        /** The signature of the message author, if provided. */
        this.signature = this.source.author_signature;
        /** The timestamp of when the message was sent (Unix time). */
        this.date = this.source.date;
        /** The timestamp of when the message was last edited, if available (Unix time). */
        this.editDate = this.source.edit_date;
        /** The ID of the message thread, if this message is part of a thread. */
        this.messageThreadID = this.source.message_thread_id;
        /** The ID of the business connection, if present. */
        this.businessConnectionID = this.source.business_connection_id;
        /** Indicates if this message is part of a topic. */
        this.isTopicMessage = this.source.is_topic_message;
        /** Indicates if the message has protected content. */
        this.hasProtectedContent = this.source.has_protected_content;
        /** The ID of the special effect applied to this message, if any. */
        this.effectID = this.source.effect_id;
        /** Indicates if this message is an automatic forward. */
        this.isAutomaticForward = this.source.is_automatic_forward;
        /** Indicates if the message was sent from offline mode. */
        this.isFromOffline = this.source.is_from_offline;
        /** The user who sent the message. */
        this.user = this.getContext({ key: 'User', source: this.source.from });
        /** The bot that forwarded the message, if any. */
        this.viaBot = this.getContext({ key: 'User', source: this.source.via_bot });
        /** The chat where the message was sent. */
        this.chat = this.getContext({ key: 'Chat', source: this.source.chat });
        /** The chat that forwarded the message, if different from the sender. */
        this.senderChat = this.getContext({ key: 'Chat', source: this.source.sender_chat });
        /** The message to which this message is a reply. */
        this.replyMessage = new MessageReply_context_1.ReplyContext(this);
        /** The origin of the forwarded message, if applicable. */
        this.forwardMessage = this.getContext({ key: 'MessageOrigin', source: this.source.forward_origin });
        /** The entities (like mentions, hashtags) present in the message. */
        this.entities = (_a = (this.source.entities || this.source.caption_entities)) === null || _a === void 0 ? void 0 : _a.map((x) => this.getContext({ key: 'MessageEntity', source: x }));
        /** The reply markup (e.g., inline keyboard) associated with the message. */
        this.replyMarkup = this.source.reply_markup;
        /** The updates related to this message. */
        this.updates = new MessageUpdates_1.MessageUpdate(this);
        /** The attachments (like photos, videos) present in the message. */
        this.attachments = new MessageAttachments_1.MessageAttachments(this);
    }
};
exports.MessageContext = MessageContext;
exports.MessageContext = MessageContext = tslib_1.__decorate([
    (0, core_1.ContextD)('Message')
], MessageContext);
