"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageMethods = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../../utils");
const core_1 = require("../../core");
class MessageMethods extends core_1.Context {
    send(data, params) {
        return this.client.api.sendMessage(Object.assign({ text: typeof data === 'string' ? data : data.text, chat_id: this.source.chat.id, business_connection_id: this.source.business_connection_id, message_thread_id: this.source.is_topic_message ? this.source.message_thread_id : undefined }, (params || (typeof data === 'object' ? data : {}))));
        // TODO: sending a message based on data from the context
    }
    sendTemplate(templateName, payload, params) {
        return this.send(Object.assign(utils_1.TemplateUtil.getTemplate(templateName, Object.assign({}, this, payload)), params));
    }
    sendQuestion(data, callback) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            var _a;
            this.client.question.addQuestion((_a = this.source.from) === null || _a === void 0 ? void 0 : _a.id, callback);
            return this.send(data);
        });
    }
    reply(data, params) {
        if (typeof data === 'string')
            params = Object.assign(params || {}, { text: data });
        else
            params = data;
        return this.send(Object.assign({ reply_to_message_id: this.source.message_id }, params));
    }
    /**
     * Forwards the current message to another chat.
     *
     * @param chat_id The ID of the chat to which the message should be forwarded.
     * @param params Optional parameters for forwarding the message.
     * @returns A promise that resolves when the message has been forwarded.
     */
    forward(chat_id, params) {
        return this.client.api.forwardMessage(Object.assign({ message_thread_id: this.source.is_topic_message ? this.source.message_thread_id : undefined, from_chat_id: this.source.chat.id, message_id: this.source.message_id, chat_id }, params));
    }
    /**
     * Deletes the current message from the chat.
     *
     * @returns A promise that resolves when the message has been successfully deleted.
     */
    delete(timeout) {
        return new Promise((res, rej) => setTimeout(() => this.client.api
            .deleteMessage({ chat_id: this.source.chat.id, message_id: this.source.message_id })
            .then(res)
            .catch(rej), timeout));
    }
    /**
     * Pins the current message in the chat.
     *
     * @param params Optional parameters for pinning the message.
     * @returns A promise that resolves when the message has been successfully pinned.
     */
    pin(params) {
        return this.client.api.pinChatMessage(Object.assign({ chat_id: this.source.chat.id, message_id: this.source.message_id }, params));
    }
    /**
     * Unpins the current message from the chat.
     *
     * @param params Optional parameters for unpinning the message.
     * @returns A promise that resolves when the message has been successfully unpinned.
     */
    unpin(params) {
        return this.client.api.unpinChatMessage(Object.assign({ chat_id: this.source.chat.id, message_id: this.source.message_id }, params));
    }
    /**
     * Sends a chat action (e.g., typing, uploading) to indicate activity in the chat.
     *
     * @param action The type of chat action to send.
     * @returns A promise that resolves when the chat action has been sent.
     */
    sendAction(action) {
        return this.client.api.sendChatAction({
            chat_id: this.source.chat.id,
            message_thread_id: this.source.is_topic_message ? this.source.message_thread_id : undefined,
            action,
        });
    }
    sendPhoto(photoOrParams, params) {
        const _a = photoOrParams instanceof Object && 'photo' in photoOrParams ? photoOrParams : Object.assign({ photo: photoOrParams }, params), { photo } = _a, restParams = tslib_1.__rest(_a, ["photo"]);
        return this.client.api.sendPhoto(Object.assign({ chat_id: this.source.chat.id, photo }, restParams));
    }
    sendVideo(videoOrParams, params) {
        const _a = videoOrParams instanceof Object && 'video' in videoOrParams ? videoOrParams : Object.assign({ video: videoOrParams }, params), { video } = _a, restParams = tslib_1.__rest(_a, ["video"]);
        return this.client.api.sendVideo(Object.assign({ chat_id: this.source.chat.id, video }, restParams));
    }
    sendAudio(audioOrParams, params) {
        const _a = audioOrParams instanceof Object && 'audio' in audioOrParams ? audioOrParams : Object.assign({ audio: audioOrParams }, params), { audio } = _a, restParams = tslib_1.__rest(_a, ["audio"]);
        return this.client.api.sendAudio(Object.assign({ chat_id: this.source.chat.id, audio }, restParams));
    }
    sendDocument(documentOrParams, params) {
        const _a = documentOrParams instanceof Object && 'document' in documentOrParams
            ? documentOrParams
            : Object.assign({ document: documentOrParams }, params), { document } = _a, restParams = tslib_1.__rest(_a, ["document"]);
        return this.client.api.sendDocument(Object.assign({ chat_id: this.source.chat.id, document }, restParams));
    }
    sendAnimation(animationOrParams, params) {
        const _a = animationOrParams instanceof Object && 'animation' in animationOrParams
            ? animationOrParams
            : Object.assign({ animation: animationOrParams }, params), { animation } = _a, restParams = tslib_1.__rest(_a, ["animation"]);
        return this.client.api.sendAnimation(Object.assign({ chat_id: this.source.chat.id, animation }, restParams));
    }
    sendMediaGroup(mediaOrParams, params) {
        const _a = Array.isArray(mediaOrParams)
            ? Object.assign({ media: mediaOrParams }, params) : mediaOrParams instanceof Object && 'media' in mediaOrParams
            ? mediaOrParams
            : Object.assign({ media: [] }, params), { media } = _a, restParams = tslib_1.__rest(_a, ["media"]);
        return this.client.api.sendMediaGroup(Object.assign({ chat_id: this.source.chat.id, media }, restParams));
    }
    /**
     * Sends a contact to the chat.
     *
     * @param params Parameters for sending the contact, excluding chat_id.
     * @returns A promise that resolves to the message context.
     */
    sendContact(params) {
        return this.client.api.sendContact(Object.assign({ chat_id: this.source.chat.id }, params));
    }
    sendDice(emojiOrParams, params) {
        const _a = typeof emojiOrParams === 'string'
            ? Object.assign({ emoji: emojiOrParams }, params) : emojiOrParams instanceof Object
            ? Object.assign({ emoji: emojiOrParams.emoji }, emojiOrParams) : Object.assign({ emoji: undefined }, params), { emoji } = _a, restParams = tslib_1.__rest(_a, ["emoji"]);
        //@ts-ignore
        return this.client.api.sendDice(Object.assign({ chat_id: this.source.chat.id, emoji: emoji ? emojiMap[emoji] : undefined }, restParams));
    }
    /**
     * Sends an invoice to the chat.
     *
     * @param params Parameters for sending the invoice, excluding chat_id.
     * @returns A promise that resolves to the message context.
     */
    sendInvoice(params) {
        return this.client.api.sendInvoice(Object.assign({ chat_id: this.source.chat.id }, params));
    }
    /**
     * Sends a location to the chat.
     *
     * @param params Parameters for sending the location, excluding chat_id.
     * @returns A promise that resolves to the message context.
     */
    sendLocation(params) {
        return this.client.api.sendLocation(Object.assign({ chat_id: this.source.chat.id }, params));
    }
    sendPaidMedia(mediaOrParams, star_count, params) {
        const _a = Array.isArray(mediaOrParams)
            ? Object.assign({ media: mediaOrParams }, params) : mediaOrParams instanceof Object && 'media' in mediaOrParams
            ? mediaOrParams
            : Object.assign({ media: [] }, params), { media, star_count: paramStarCount } = _a, restParams = tslib_1.__rest(_a, ["media", "star_count"]);
        return this.client.api.sendPaidMedia(Object.assign({ chat_id: this.source.chat.id, media, star_count: star_count !== null && star_count !== void 0 ? star_count : paramStarCount }, restParams));
    }
    sendPoll(questionOrParams, options, params) {
        const _a = typeof questionOrParams === 'string'
            ? Object.assign({ question: questionOrParams, options: options }, params) : questionOrParams instanceof Object && 'question' in questionOrParams
            ? questionOrParams
            : Object.assign({ question: '', options: [] }, params), { question, options: optionsArray } = _a, restParams = tslib_1.__rest(_a, ["question", "options"]);
        return this.client.api.sendPoll(Object.assign({ chat_id: this.source.chat.id, question, options: optionsArray }, restParams));
    }
    sendSticker(stickerOrParams, params) {
        const _a = stickerOrParams instanceof Object && 'sticker' in stickerOrParams ? stickerOrParams : Object.assign({ sticker: stickerOrParams }, params), { sticker } = _a, restParams = tslib_1.__rest(_a, ["sticker"]);
        return this.client.api.sendSticker(Object.assign({ chat_id: this.source.chat.id, sticker }, restParams));
    }
    /**
     * Sends a venue to the chat.
     *
     * @param params Parameters for sending the venue, excluding chat_id.
     * @returns A promise that resolves to the message context.
     */
    sendVenue(params) {
        return this.client.api.sendVenue(Object.assign({ chat_id: this.source.chat.id }, params));
    }
    sendVideoNote(paramsOrVideoNote, params) {
        const _a = paramsOrVideoNote instanceof Object && 'video_note' in paramsOrVideoNote
            ? paramsOrVideoNote
            : Object.assign({ video_note: paramsOrVideoNote }, params), { video_note } = _a, restParams = tslib_1.__rest(_a, ["video_note"]);
        return this.client.api.sendVideoNote(Object.assign({ chat_id: this.source.chat.id, video_note }, restParams));
    }
    sendVoice(paramsOrVoice, params) {
        const _a = paramsOrVoice instanceof Object && 'voice' in paramsOrVoice ? paramsOrVoice : Object.assign({ voice: paramsOrVoice }, params), { voice } = _a, restParams = tslib_1.__rest(_a, ["voice"]);
        return this.client.api.sendVoice(Object.assign({ chat_id: this.source.chat.id, voice }, restParams));
    }
    /**
     * Retrieves the database message associated with the current message.
     *
     * @returns A promise that resolves to the database message context.
     */
    getMessageDB() {
        return this.client.database.message.getMessage(this.source.chat.id, this.source.message_id);
    }
}
exports.MessageMethods = MessageMethods;
