import { TelegramMessageOrigin, TelegramMessageOriginChannel, TelegramMessageOriginChat, TelegramMessageOriginHiddenUser, TelegramMessageOriginUser } from '../../../types';
import { Context } from '../../core';
import * as Contexts from '../../../migrated';
/**
 * MessageOriginContext handles the source information of a message's origin,
 * including user, hidden user, chat, or channel.
 */
export declare class MessageOriginContext extends Context<TelegramMessageOrigin> {
    /** The type of the message origin (e.g., user, chat, channel, etc.) */
    type: "channel" | "user" | "hidden_user" | "chat";
    /** The date when the message was sent */
    date: number;
    /** Retrieves the context for a user origin if the message is from a user. */
    user: Contexts.MessageOriginUserContext;
    /** Retrieves the context for a hidden user origin if the message is from a hidden user. */
    hiddenUser: Contexts.MessageOriginHiddenUserContext;
    /** Retrieves the context for a chat origin if the message is from a chat. */
    chat: Contexts.MessageOriginChatContext;
    /** Retrieves the context for a channel origin if the message is from a channel. */
    channel: Contexts.MessageOriginChannelContext;
}
/**
 * MessageOriginUserContext handles the context of a message sent by a specific user.
 */
export declare class MessageOriginUserContext extends Context<TelegramMessageOriginUser> {
    /** Retrieves the context for the user who sent the message. */
    user: Contexts.UserContext;
}
/**
 * MessageOriginHiddenUserContext handles the context of a message sent by a hidden user.
 */
export declare class MessageOriginHiddenUserContext extends Context<TelegramMessageOriginHiddenUser> {
    /** The username of the hidden user who sent the message */
    username: string;
}
/**
 * MessageOriginChatContext handles the context of a message sent within a chat.
 */
export declare class MessageOriginChatContext extends Context<TelegramMessageOriginChat> {
    /** Retrieves the context for the chat from which the message was sent. */
    chat: Contexts.ChatContext;
    /** The signature of the message's author, if available */
    signature: string | undefined;
}
/**
 * MessageOriginChannelContext handles the context of a message sent within a channel.
 */
export declare class MessageOriginChannelContext extends Context<TelegramMessageOriginChannel> {
    /** The ID of the message in the channel */
    messageID: number;
    /** Retrieves the context for the chat (channel) from which the message was sent. */
    chat: Contexts.ChatContext;
    /** The signature of the message's author, if available */
    signature: string | undefined;
}
