"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageOriginChannelContext = exports.MessageOriginChatContext = exports.MessageOriginHiddenUserContext = exports.MessageOriginUserContext = exports.MessageOriginContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
/**
 * MessageOriginContext handles the source information of a message's origin,
 * including user, hidden user, chat, or channel.
 */
let MessageOriginContext = class MessageOriginContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** The type of the message origin (e.g., user, chat, channel, etc.) */
        this.type = this.source.type;
        /** The date when the message was sent */
        this.date = this.source.date;
        /** Retrieves the context for a user origin if the message is from a user. */
        this.user = this.getContext({ key: 'MessageOriginUser', source: this.source });
        /** Retrieves the context for a hidden user origin if the message is from a hidden user. */
        this.hiddenUser = this.getContext({ key: 'MessageOriginHiddenUser', source: this.source });
        /** Retrieves the context for a chat origin if the message is from a chat. */
        this.chat = this.getContext({ key: 'MessageOriginChat', source: this.source });
        /** Retrieves the context for a channel origin if the message is from a channel. */
        this.channel = this.getContext({ key: 'MessageOriginChannel', source: this.source });
    }
};
exports.MessageOriginContext = MessageOriginContext;
exports.MessageOriginContext = MessageOriginContext = tslib_1.__decorate([
    (0, core_1.ContextD)('MessageOrigin')
], MessageOriginContext);
/**
 * MessageOriginUserContext handles the context of a message sent by a specific user.
 */
let MessageOriginUserContext = class MessageOriginUserContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** Retrieves the context for the user who sent the message. */
        this.user = this.getContext({ key: 'User', source: this.source.sender_user });
    }
};
exports.MessageOriginUserContext = MessageOriginUserContext;
exports.MessageOriginUserContext = MessageOriginUserContext = tslib_1.__decorate([
    (0, core_1.ContextD)('MessageOriginUser')
], MessageOriginUserContext);
/**
 * MessageOriginHiddenUserContext handles the context of a message sent by a hidden user.
 */
let MessageOriginHiddenUserContext = class MessageOriginHiddenUserContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** The username of the hidden user who sent the message */
        this.username = this.source.sender_user_name;
    }
};
exports.MessageOriginHiddenUserContext = MessageOriginHiddenUserContext;
exports.MessageOriginHiddenUserContext = MessageOriginHiddenUserContext = tslib_1.__decorate([
    (0, core_1.ContextD)('MessageOriginHiddenUser')
], MessageOriginHiddenUserContext);
/**
 * MessageOriginChatContext handles the context of a message sent within a chat.
 */
let MessageOriginChatContext = class MessageOriginChatContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** Retrieves the context for the chat from which the message was sent. */
        this.chat = this.getContext({ key: 'Chat', source: this.source.sender_chat });
        /** The signature of the message's author, if available */
        this.signature = this.source.author_signature;
    }
};
exports.MessageOriginChatContext = MessageOriginChatContext;
exports.MessageOriginChatContext = MessageOriginChatContext = tslib_1.__decorate([
    (0, core_1.ContextD)('MessageOriginChat')
], MessageOriginChatContext);
/**
 * MessageOriginChannelContext handles the context of a message sent within a channel.
 */
let MessageOriginChannelContext = class MessageOriginChannelContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** The ID of the message in the channel */
        this.messageID = this.source.message_id;
        /** Retrieves the context for the chat (channel) from which the message was sent. */
        this.chat = this.getContext({ key: 'Chat', source: this.source.chat });
        /** The signature of the message's author, if available */
        this.signature = this.source.author_signature;
    }
};
exports.MessageOriginChannelContext = MessageOriginChannelContext;
exports.MessageOriginChannelContext = MessageOriginChannelContext = tslib_1.__decorate([
    (0, core_1.ContextD)('MessageOriginChannel')
], MessageOriginChannelContext);
