import { Context } from '../../core';
import { TelegramMessage } from '../../../types';
import { MessageContext, UserContext } from '../../../migrated';
/**
 * MessageUpdate handles updates related to a specific Telegram message,
 * including new members, left members, title changes, and more.
 */
export declare class MessageUpdate extends Context<TelegramMessage> {
    /** The boost count for a chat, if available */
    boostedChat: number | undefined;
    /** Retrieves the context for new members added to the chat. */
    newChatMember: UserContext[] | undefined;
    /** Retrieves the context for a member who left the chat. */
    leftChatMember: UserContext | undefined;
    /** The new title of the chat, if it was updated */
    newChatTitle: string | undefined;
    /** The new photo of the chat, if it was updated */
    newChatPhoto: import("../../../types").TelegramPhotoSize[] | undefined;
    /** The ID of the chat this group was migrated to, if applicable */
    migrateToChatID: number | undefined;
    /** The ID of the chat this group was migrated from, if applicable */
    migrateFromChatID: number | undefined;
    /** The connected website associated with the message, if available */
    connectedWebsite: string | undefined;
    /** The giveaway winners related to the message, if applicable */
    giveawayWinners: import("../../../types").TelegramGiveawayWinners | undefined;
    /**
     * The pinned message, if applicable.
     * Contains the content or reference to a message that has been pinned in the chat.
     */
    pinnedMessage: MessageContext;
}
