"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageUpdate = void 0;
const core_1 = require("../../core");
/**
 * MessageUpdate handles updates related to a specific Telegram message,
 * including new members, left members, title changes, and more.
 */
class MessageUpdate extends core_1.Context {
    constructor() {
        var _a;
        super(...arguments);
        /** The boost count for a chat, if available */
        this.boostedChat = this.source.sender_boost_count;
        /** Retrieves the context for new members added to the chat. */
        this.newChatMember = (_a = this.source.new_chat_members) === null || _a === void 0 ? void 0 : _a.map((x) => this.getContext({ key: 'User', source: x }));
        /** Retrieves the context for a member who left the chat. */
        this.leftChatMember = this.getContext({ key: 'User', source: this.source.left_chat_member });
        /** The new title of the chat, if it was updated */
        this.newChatTitle = this.source.new_chat_title;
        /** The new photo of the chat, if it was updated */
        this.newChatPhoto = this.source.new_chat_photo;
        /** The ID of the chat this group was migrated to, if applicable */
        this.migrateToChatID = this.source.migrate_to_chat_id;
        /** The ID of the chat this group was migrated from, if applicable */
        this.migrateFromChatID = this.source.migrate_from_chat_id;
        /** The connected website associated with the message, if available */
        this.connectedWebsite = this.source.connected_website;
        /** The giveaway winners related to the message, if applicable */
        this.giveawayWinners = this.source.giveaway_winners;
        /**
         * The pinned message, if applicable.
         * Contains the content or reference to a message that has been pinned in the chat.
         */
        this.pinnedMessage = this.getContext({ key: 'Message', source: this.source.pinned_message });
    }
}
exports.MessageUpdate = MessageUpdate;
