"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PollContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
let PollContext = class PollContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** Gets the ID of the poll. */
        this.id = this.source.id;
        /** Gets the question text of the poll. */
        this.question = this.source.question;
        /** Gets the list of poll options. */
        this.options = this.source.options;
        /** Gets the total number of users that voted in the poll. */
        this.totalVoterCount = this.source.total_voter_count;
        /** Returns true if the poll is closed. */
        this.isClosed = this.source.is_closed;
        /** Returns true if the poll is anonymous. */
        this.isAnonymous = this.source.is_anonymous;
        /** Gets the type of the poll. */
        this.type = this.source.type;
        /** Returns true if the poll allows multiple answers. */
        this.allowsMultipleAnswers = this.source.allows_multiple_answers;
        /** Gets the ID of the correct answer option, if specified. */
        this.correctOptionId = this.source.correct_option_id;
        /** Gets the text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, if specified. */
        this.explanation = this.source.explanation;
        /** Gets the entities that appear in the explanation text, if specified. */
        this.explanationEntities = this.getContext({ key: 'MessageEntity', source: this.source.explanation_entities });
        /** Special entities that appear in the question. Currently, only custom emoji entities are allowed in poll questions */
        this.questionEntities = this.getContext({ key: 'MessageEntity', source: this.source.question_entities });
        /** Gets the amount of time in seconds the poll will be active after creation, if specified. */
        this.openPeriod = this.source.open_period;
    }
    /**
     * This method searches for a poll option with the given text among all the options in the poll.
     * @param text Parameter specifies the text to search for.
     * @returns The found poll option.
     */
    getPollOptionByText(text) {
        const findResult = this.source.options.find((option) => option.text === text);
        return findResult;
    }
    /**
     * Returns the percentage of votes for the transmitted option
     * @param option Poll option from which to calculate the percentage
     * @returns Percentage of those who voted for option
     */
    getPollOptionPercentage(option) {
        const totalVoters = this.source.total_voter_count;
        return (option.voter_count / totalVoters) * 100;
    }
};
exports.PollContext = PollContext;
exports.PollContext = PollContext = tslib_1.__decorate([
    (0, core_1.ContextD)('Poll')
], PollContext);
