import { TelegramAnswerCallbackQueryParams, TelegramCallbackQuery } from '../../../types';
import { Context } from '../../core';
import { IncomingMessageContext, UserContext } from '../../../migrated';
export declare class CallbackQueryContext extends Context<TelegramCallbackQuery> {
    /** The user who triggered the callback query. */
    user: UserContext;
    /** The message context associated with the callback query, if available. */
    message: IncomingMessageContext;
    /** The ID of the callback query. */
    id: string;
    /** The data associated with the callback query. */
    data: string | Record<string, any>;
    /** The ID of the inline message that was sent with the button that triggered the callback query, if available. */
    inlineMessageID: string | undefined;
    /** The chat instance that was used to generate the inline button, if available. */
    chatInstance: string;
    /** The short name of the game to be returned, if this callback query is from a game message. */
    gameShortName: string | undefined;
    /**
     * Answers the callback query with the specified parameters.
     * @param params - The parameters to use for answering the callback query.
     * @returns A Promise that resolves with the result of the API call to answer the callback query.
     */
    answer(params?: Partial<TelegramAnswerCallbackQueryParams>): Promise<boolean>;
}
