"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallbackQueryContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
let CallbackQueryContext = class CallbackQueryContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** The user who triggered the callback query. */
        this.user = this.getContext({ key: 'User', source: this.source.from });
        /** The message context associated with the callback query, if available. */
        this.message = this.getContext({ key: 'IncomingMessage', source: this.source.message });
        /** The ID of the callback query. */
        this.id = this.source.id;
        /** The data associated with the callback query. */
        this.data = (this.state.callbackData || this.source.data);
        /** The ID of the inline message that was sent with the button that triggered the callback query, if available. */
        this.inlineMessageID = this.source.inline_message_id;
        /** The chat instance that was used to generate the inline button, if available. */
        this.chatInstance = this.source.chat_instance;
        /** The short name of the game to be returned, if this callback query is from a game message. */
        this.gameShortName = this.source.game_short_name;
    }
    /**
     * Answers the callback query with the specified parameters.
     * @param params - The parameters to use for answering the callback query.
     * @returns A Promise that resolves with the result of the API call to answer the callback query.
     */
    answer(params) {
        return this.client.api.answerCallbackQuery(Object.assign({ callback_query_id: this.source.id }, params));
    }
};
exports.CallbackQueryContext = CallbackQueryContext;
exports.CallbackQueryContext = CallbackQueryContext = tslib_1.__decorate([
    (0, core_1.ContextD)('CallbackQuery')
], CallbackQueryContext);
