import { TelegramChatInviteLink, TelegramChatJoinRequest } from '../../../types';
import { Context } from '../../core';
import { ChatContext, UserContext } from '../../../migrated';
export declare class ChatJoinRequestContext extends Context<TelegramChatJoinRequest> {
    /** User that sent the join request. */
    user: UserContext;
    /** Chat to which the request was sent. */
    chat: ChatContext;
    /** Optional. Chat invite link that was used by the user to send the join request. */
    inviteLink: TelegramChatInviteLink | undefined;
    /** Identifier of a private chat with the user who sent the join request. Can be used for direct communication for up to 5 minutes after the request is sent. */
    userChatId: number;
    /** Date the request was sent in Unix time. */
    date: number;
    /** Optional. Bio of the user who sent the join request. */
    bio: string | undefined;
    /**
     * Approves the join request, allowing the user to join the chat.
     *
     * @returns A Promise that resolves with the result of the API call to approve the chat join request.
     */
    approve(): Promise<boolean>;
    /**
     * Declines the join request, preventing the user from joining the chat.
     *
     * @returns A Promise that resolves with the result of the API call to decline the chat join request.
     */
    decline(): Promise<boolean>;
}
