"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatJoinRequestContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
let ChatJoinRequestContext = class ChatJoinRequestContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** User that sent the join request. */
        this.user = this.getContext({ key: 'User', source: this.source.from });
        /** Chat to which the request was sent. */
        this.chat = this.getContext({ key: 'Chat', source: this.source.chat });
        /** Optional. Chat invite link that was used by the user to send the join request. */
        this.inviteLink = this.getContext({ key: 'ChatInviteLink', source: this.source.invite_link });
        /** Identifier of a private chat with the user who sent the join request. Can be used for direct communication for up to 5 minutes after the request is sent. */
        this.userChatId = this.source.user_chat_id;
        /** Date the request was sent in Unix time. */
        this.date = this.source.date;
        /** Optional. Bio of the user who sent the join request. */
        this.bio = this.source.bio;
    }
    /**
     * Approves the join request, allowing the user to join the chat.
     *
     * @returns A Promise that resolves with the result of the API call to approve the chat join request.
     */
    approve() {
        return this.client.api.approveChatJoinRequest({ chat_id: this.source.chat.id, user_id: this.source.from.id });
    }
    /**
     * Declines the join request, preventing the user from joining the chat.
     *
     * @returns A Promise that resolves with the result of the API call to decline the chat join request.
     */
    decline() {
        return this.client.api.declineChatJoinRequest({ chat_id: this.source.chat.id, user_id: this.source.from.id });
    }
};
exports.ChatJoinRequestContext = ChatJoinRequestContext;
exports.ChatJoinRequestContext = ChatJoinRequestContext = tslib_1.__decorate([
    (0, core_1.ContextD)('ChatJoinRequest')
], ChatJoinRequestContext);
