"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShippingQueryContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
let ShippingQueryContext = class ShippingQueryContext extends core_1.Context {
    constructor() {
        super(...arguments);
        /** User who sent the shipping query. */
        this.user = this.getContext({ key: 'User', source: this.source.from });
        /** Unique identifier for the shipping query. */
        this.id = this.source.id;
        /** Bot-specified invoice payload associated with the shipping query. */
        this.invoicePayload = this.source.invoice_payload;
        /** User-specified shipping address associated with the shipping query. */
        this.shippingAddress = this.source.shipping_address;
    }
    /**
     * Answers the shipping query with the specified parameters.
     *
     * @param params - The parameters to use for answering the shipping query.
     * @returns A Promise that resolves with the result of the API call to answer the shipping query.
     */
    answer(params) {
        return this.client.api.answerShippingQuery(Object.assign({ shipping_query_id: this.source.id, ok: true }, params));
    }
};
exports.ShippingQueryContext = ShippingQueryContext;
exports.ShippingQueryContext = ShippingQueryContext = tslib_1.__decorate([
    (0, core_1.ContextD)('ShippingQuery')
], ShippingQueryContext);
