"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("../../core");
let UpdateContext = class UpdateContext extends core_1.Context {
    constructor(contextParams) {
        var _a;
        super(contextParams);
        /** The ID of the update. */
        this.id = this.source.update_id;
        // prettier-ignore
        /** The type of the update determined based on the presence of specific properties in the source. */
        this.name = this.source.message && "message" ||
            this.source.edited_message && "edited_message" ||
            this.source.channel_post && "channel_post" ||
            this.source.edited_channel_post && "edited_channel_post" ||
            this.source.business_connection && "business_connection" ||
            this.source.business_message && "business_message" ||
            this.source.edited_business_message && "edited_business_message" ||
            this.source.deleted_business_messages && "deleted_business_messages" ||
            this.source.message_reaction && "message_reaction" ||
            this.source.message_reaction_count && "message_reaction_count" ||
            this.source.inline_query && "inline_query" ||
            this.source.chosen_inline_result && "chosen_inline_result" ||
            this.source.callback_query && "callback_query" ||
            this.source.shipping_query && "shipping_query" ||
            this.source.pre_checkout_query && "pre_checkout_query" ||
            this.source.poll && "poll" ||
            this.source.poll_answer && "poll_answer" ||
            this.source.my_chat_member && "my_chat_member" ||
            this.source.chat_member && "chat_member" ||
            this.source.chat_join_request && "chat_join_request" ||
            this.source.chat_boost && "chat_boost" ||
            this.source.removed_chat_boost && "removed_chat_boost";
        this.message = this.getContext({ key: 'Message', source: this.source.message });
        this.edited_message = this.getContext({ key: 'Message', source: this.source.edited_message });
        this.channel_post = this.getContext({ key: 'Message', source: this.source.channel_post });
        this.edited_channel_post = this.getContext({ key: 'Message', source: this.source.edited_channel_post });
        this.business_connection = this.getContext({ key: 'Message', source: this.source.business_connection });
        this.business_message = this.getContext({ key: 'Message', source: this.source.business_message });
        this.edited_business_message = this.getContext({ key: 'Message', source: this.source.edited_business_message });
        this.deleted_business_messages = this.getContext({ key: 'Message', source: this.source.deleted_business_messages });
        this.message_reaction = this.getContext({ key: 'MessageReaction', source: this.source.message_reaction });
        this.message_reaction_count = this.getContext({ key: 'MessageReactionCount', source: this.source.message_reaction_count });
        this.inline_query = this.getContext({ key: 'InlineQuery', source: this.source.inline_query });
        this.chosen_inline_result = this.getContext({ key: 'ChosenInlineResult', source: this.source.chosen_inline_result });
        this.callback_query = this.getContext({ key: 'CallbackQuery', source: this.source.callback_query });
        this.shipping_query = this.getContext({ key: 'ShippingQuery', source: this.source.shipping_query });
        this.pre_checkout_query = this.getContext({ key: 'PreCheckoutQuery', source: this.source.pre_checkout_query });
        this.poll = this.getContext({ key: 'Poll', source: this.source.poll });
        this.poll_answer = this.getContext({ key: 'PollAnswer', source: this.source.poll_answer });
        this.my_chat_member = this.getContext({ key: 'ChatMemberUpdated', source: this.source.my_chat_member });
        this.chat_member = this.getContext({ key: 'ChatMemberUpdated', source: this.source.chat_member });
        this.chat_join_request = this.getContext({ key: 'ChatJoinRequest', source: this.source.chat_join_request });
        this.chat_boost = this.getContext({ key: 'ChatBoost', source: this.source.chat_boost });
        this.removed_chat_boost = this.getContext({ key: 'RemovedChatBoost', source: this.source.removed_chat_boost });
        this.service_message = this.getContext({ key: 'ServiceMessage', source: this.source.message });
        //@ts-ignore
        if ((_a = this.serviceMessage) === null || _a === void 0 ? void 0 : _a.name)
            this.name = 'service_message';
    }
};
exports.UpdateContext = UpdateContext;
exports.UpdateContext = UpdateContext = tslib_1.__decorate([
    (0, core_1.ContextD)('Update'),
    tslib_1.__metadata("design:paramtypes", [Object])
], UpdateContext);
