"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatabaseManager = void 0;
const tslib_1 = require("tslib");
const typeorm_1 = require("typeorm");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const migrated_1 = require("../migrated/");
const __1 = require("../");
const crypto_1 = require("crypto");
const entities_1 = require("./entities");
const Config_service_1 = require("./Config.service");
const Config_entity_1 = require("./entities/Config.entity");
const Message_entity_1 = require("./entities/Message.entity");
const Message_service_1 = require("./services/Message.service");
class DatabaseManager {
    constructor(client) {
        this.client = client;
        this.password = (0, crypto_1.createHash)('sha1')
            .update((Date.now() + Math.random()).toString())
            .digest('hex');
    }
    init() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            var _a;
            if (this.db)
                return this;
            console.log(`\x1b[34m❯\x1b[0m Send "${this.password}" to get the owner status`);
            if (!fs_1.default.existsSync(this.client.directory))
                fs_1.default.mkdirSync(this.client.directory, { recursive: true });
            this.db = new typeorm_1.DataSource(//@ts-ignore
            this.client.params.database
                ? Object.assign(Object.assign({}, this.client.params.database), { entities: [Message_entity_1.MessageEntity, migrated_1.UserEntity, migrated_1.CallbackDataEntity, Config_entity_1.ConfigEntity] }) : {
                type: 'sqlite',
                database: path_1.default.join(this.client.directory, 'database.db'),
                entities: [Message_entity_1.MessageEntity, migrated_1.UserEntity, migrated_1.CallbackDataEntity, Config_entity_1.ConfigEntity, entities_1.ChatEntity],
                synchronize: true, // Синхронизация создает таблицы, если их нет
            });
            yield this.db.initialize();
            this.config = new Config_service_1.ConfigService(this.db);
            this.message = new Message_service_1.MessageService(this.client, this.db);
            if ((_a = this.client.params.dbConfig) === null || _a === void 0 ? void 0 : _a.messageLifetime)
                this.db
                    .getRepository(Message_entity_1.MessageEntity)
                    .delete({ created_at: (0, typeorm_1.LessThan)(new Date(Date.now() - this.client.params.dbConfig.messageLifetime)) });
            return this;
        });
    }
    // Получаем данные пользователя с использованием репозитория TypeORM
    getUser(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const userRepository = this.db.getRepository(migrated_1.UserEntity);
            const user = yield userRepository.findOne({ where: { user_id: id } });
            if (!user)
                return null;
            return __1.ContextManager.getContext('UserDB', { client: this.client, source: user });
        });
    }
    // Пример метода для добавления пользователя
    addUser(userData) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.db.getRepository(migrated_1.UserEntity);
            return yield repository.save(userData);
        });
    }
    addCallbackData(data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.db.getRepository(migrated_1.CallbackDataEntity);
            const button_id = (0, crypto_1.createHash)('sha1').update(JSON.stringify(data)).digest('hex').slice(0, 12);
            return (yield this.getCallbackData(button_id)) || (yield repository.save(Object.assign(Object.assign({}, data), { button_id })));
        });
    }
    getCallbackData(button_id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.db.getRepository(migrated_1.CallbackDataEntity);
            return repository.findOne({
                where: { button_id },
                select: ['button_id', 'command', 'isBackButton', 'onClick', 'onlyForUser', 'payload'],
            });
        });
    }
    // Получаем данные пользователя с использованием репозитория TypeORM
    getChat(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.db.getRepository(entities_1.ChatEntity);
            const chat = yield repository.findOne({ where: { chat_id: id } });
            if (!chat)
                return null;
            return __1.ContextManager.getContext('ChatDB', { client: this.client, source: chat });
        });
    }
    // Пример метода для добавления пользователя
    addChat(userData) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const repository = this.db.getRepository(entities_1.ChatEntity);
            return yield repository.save(userData);
        });
    }
}
exports.DatabaseManager = DatabaseManager;
