"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatDBContext = void 0;
const tslib_1 = require("tslib");
const contexts_1 = require("../../contexts");
const entities_1 = require("../entities");
let ChatDBContext = class ChatDBContext extends contexts_1.Context {
    constructor() {
        super(...arguments);
        this.id = this.source.chat_id;
        this._createdAt = this.initCreatedAt();
        this._lastActivity = this.source.last_activity || Date.now();
        this._status = this.source.status || 0;
        this._payload = this.initPayload();
        this.saveTimeout = null;
    }
    get createdAt() { return this._createdAt; }
    set createdAt(value) { this._createdAt = value; this.save({ created_at: value }); }
    get lastActivity() { return Number(this._lastActivity); }
    set lastActivity(value) { this._lastActivity = value; this.save({ last_activity: new Date(value) }); }
    get status() { return Number(this._status); }
    set status(value) { this._status = value; this.save({ status: value }); }
    set payload(value) { this._payload = value; this.save({ payload: value }); }
    get payload() {
        return new Proxy(this._payload, {
            set: (target, property, value) => {
                //@ts-ignore
                target[property] = value;
                this.save({ payload: target });
                return true;
            },
            get: (target, property) => {
                const value = target[property];
                if (value && typeof value === 'object') {
                    return new Proxy(value, {
                        set: (obj, prop, val) => {
                            obj[prop] = val;
                            this.save({ payload: target });
                            return true;
                        },
                    });
                }
                return value;
            },
        });
    }
    initCreatedAt() {
        return this.source.created_at ? new Date(this.source.created_at) : new Date();
    }
    initPayload() {
        var _a;
        return ((_a = this.source) === null || _a === void 0 ? void 0 : _a.payload) || this.structure(this.source);
    }
    save(data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this.saveTimeout)
                clearTimeout(this.saveTimeout);
            this.saveTimeout = setTimeout(() => tslib_1.__awaiter(this, void 0, void 0, function* () {
                try {
                    yield this.saveToDatabase(data);
                }
                catch (error) {
                    console.log(error);
                }
            }), 1000);
        });
    }
    saveToDatabase(data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const chatRepository = this.client.database.db.getRepository(entities_1.ChatEntity);
            const isSaved = yield chatRepository.countBy({ chat_id: this.id });
            if (!isSaved)
                yield chatRepository.save(Object.assign({ chat_id: this.id }, data));
            else
                yield chatRepository.update({ chat_id: this.id }, data);
        });
    }
    structure(entity) {
        return {};
    }
};
exports.ChatDBContext = ChatDBContext;
exports.ChatDBContext = ChatDBContext = tslib_1.__decorate([
    (0, contexts_1.ContextD)('ChatDB')
], ChatDBContext);
