"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserDBContext = void 0;
const tslib_1 = require("tslib");
const contexts_1 = require("../../contexts");
const migrated_1 = require("../../migrated");
const Message_entity_1 = require("../entities/Message.entity");
let UserDBContext = class UserDBContext extends contexts_1.Context {
    constructor() {
        super(...arguments);
        this.id = this.source.telegram_data.id;
        this.telegramData = contexts_1.ContextManager.getContext('User', {
            client: this.client,
            source: this.source.telegram_data,
            state: this.state,
        });
        this._createdAt = this.initCreatedAt();
        this._lastActivity = this.source.last_activity || Date.now();
        this._accessLevel = this.source.access_level || 0;
        this._banned = this.source.banned || false;
        this._language = this.source.language || this.source.telegram_data.language_code;
        this._payload = this.initPayload();
        this.history = this.initHistory();
    }
    get createdAt() { return this._createdAt; }
    set createdAt(value) { this._createdAt = value; this.save({ created_at: value }); }
    get lastActivity() { return Number(this._lastActivity); }
    set lastActivity(value) { this._lastActivity = value; this.save({ last_activity: new Date(value) }); }
    get accessLevel() { return Number(this._accessLevel); }
    set accessLevel(value) { this._accessLevel = value; this.save({ access_level: value }); }
    get banned() { return Boolean(this._banned); }
    set banned(value) { this._banned = value; this.save({ banned: value }); }
    get language() { return this._language; }
    set language(value) { this._language = value; this.save({ language: value }); }
    set payload(value) { this._payload = value; this.save({ payload: value }); }
    get payload() {
        // Создаем прокси для автоматического сохранения при изменении любого поля
        return new Proxy(this._payload, {
            set: (target, property, value) => {
                //@ts-ignore
                target[property] = value;
                this.save({ payload: target }); // Сохраняем при любом изменении
                return true;
            },
            get: (target, property) => {
                const value = target[property];
                // Если значение - объект, также оборачиваем его в прокси
                if (value && typeof value === 'object') {
                    return new Proxy(value, {
                        set: (obj, prop, val) => {
                            obj[prop] = val;
                            this.save({ payload: target }); // Сохраняем при изменении вложенного объекта
                            return true;
                        },
                    });
                }
                return value;
            },
        });
    }
    initCreatedAt() {
        return this.source.created_at ? new Date(this.source.created_at) : new Date();
    }
    initPayload() {
        var _a;
        return ((_a = this.source) === null || _a === void 0 ? void 0 : _a.payload) || this.structure(this.source);
    }
    initHistory() {
        var _a;
        return (((_a = this.source.history) === null || _a === void 0 ? void 0 : _a.map((x) => ({
            //@ts-ignore
            command: migrated_1.CommandManager.commands.find((y) => { var _a; return ((_a = y.params) === null || _a === void 0 ? void 0 : _a.name) === x.command; }),
            arguments: x.arguments,
            chat_id: x.chat_id,
        }))) || []);
    }
    getBotMessages() {
        return this.client.database.db.getRepository(Message_entity_1.MessageEntity).findBy({ chat_id: this.id });
    }
    save(data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                yield this.saveToDatabase(data);
            }
            catch (error) {
                console.log(error);
            }
        });
    }
    prepareHistory(history) {
        const processedHistory = (history || this.history)
            .slice(-50)
            .filter((x) => x.command)
            .map((x) => {
            var _a, _b;
            return ({
                arguments: x.arguments,
                //@ts-ignore
                command: typeof x.command === 'function' ? (_b = (_a = migrated_1.CommandManager.commands.find((y) => x.command.name === y.name)) === null || _a === void 0 ? void 0 : _a.params) === null || _b === void 0 ? void 0 : _b.name : x.command,
                chat_id: x.chat_id,
            });
        });
        // Удаляем последовательные дубликаты, оставляя только последний элемент
        return processedHistory.reduce((acc, current, index) => {
            var _a;
            if (current.command !== ((_a = processedHistory[index + 1]) === null || _a === void 0 ? void 0 : _a.command))
                acc.push(current);
            return acc;
        }, []);
    }
    saveToDatabase(data) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const userRepository = this.client.database.db.getRepository(migrated_1.UserEntity);
            const isSaved = yield userRepository.countBy({ user_id: this.id });
            if (!isSaved)
                yield userRepository.save(Object.assign({ user_id: this.id, telegram_data: this.telegramData.source }, data));
            else
                yield userRepository.update({ user_id: this.id }, data);
        });
    }
    structure(entity) {
        return {};
    }
    saveHistory() {
        return this.client.database.db.getRepository(migrated_1.UserEntity).update({ user_id: this.id }, { history: this.prepareHistory() });
    }
};
exports.UserDBContext = UserDBContext;
exports.UserDBContext = UserDBContext = tslib_1.__decorate([
    (0, contexts_1.ContextD)('UserDB')
], UserDBContext);
