"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageService = void 0;
const tslib_1 = require("tslib");
const typeorm_1 = require("typeorm");
const Message_entity_1 = require("../entities/Message.entity");
class MessageService {
    constructor(client, dataSource) {
        this.client = client;
        this.dataSource = dataSource;
    }
    addMessage(message) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const messageRepository = this.dataSource.getRepository(Message_entity_1.MessageEntity);
            // Проверяем существование сообщения
            const existingMessage = yield messageRepository.findOne({
                where: { message_id: message.message_id },
            });
            if (existingMessage) {
                // Если сообщение существует, обновляем его
                yield messageRepository.update({ message_id: message.message_id }, message);
            }
            else {
                // Если сообщение новое, сохраняем его
                yield messageRepository.save(message);
            }
            // Если у сообщения нет payload и есть chat_id, проверяем количество сообщений
            if (!message.payload && message.chat_id)
                // Получаем все сообщения без payload для данного чата, сортированные по дате создания (сначала новые)
                messageRepository
                    .find({
                    where: {
                        chat_id: message.chat_id,
                        payload: (0, typeorm_1.IsNull)(),
                        deleted: false,
                    },
                    order: {
                        created_at: 'DESC',
                    },
                })
                    .then((messages) => {
                    var _a, _b;
                    // Если сообщений больше 10, удаляем лишние
                    if (messages.length > (((_a = this.client.params.dbConfig) === null || _a === void 0 ? void 0 : _a.maxMessages) || 10)) {
                        const messagesToDelete = messages.slice(((_b = this.client.params.dbConfig) === null || _b === void 0 ? void 0 : _b.maxMessages) || 10);
                        messageRepository.delete({ id: (0, typeorm_1.In)(messagesToDelete.map((msg) => msg.id)) });
                    }
                });
            else if (message.payload && message.chat_id)
                // Если сообщение имеет payload и chat_id, проверяем количество сообщений
                messageRepository
                    .find({
                    where: {
                        chat_id: message.chat_id,
                        payload: (0, typeorm_1.Not)((0, typeorm_1.IsNull)()),
                        deleted: false,
                    },
                    order: {
                        created_at: 'DESC',
                    },
                })
                    .then((messages) => {
                    var _a, _b;
                    // Если сообщений больше 10, удаляем лишние
                    if (messages.length > (((_a = this.client.params.dbConfig) === null || _a === void 0 ? void 0 : _a.maxMessagesPayload) || 100)) {
                        const messagesToDelete = messages.slice(((_b = this.client.params.dbConfig) === null || _b === void 0 ? void 0 : _b.maxMessagesPayload) || 100);
                        messageRepository.delete({ id: (0, typeorm_1.In)(messagesToDelete.map((msg) => msg.id)) });
                    }
                });
        });
    }
    updateMessage(id, message) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const messageRepository = this.dataSource.getRepository(Message_entity_1.MessageEntity);
            return messageRepository.update({ message_id: id }, message);
        });
    }
    getMessage(chat, id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const messageRepository = this.dataSource.getRepository(Message_entity_1.MessageEntity);
            return messageRepository.findOne({ where: { chat_id: chat, message_id: id.toString() } });
        });
    }
    deleteMessages(ids) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const messageRepository = this.dataSource.getRepository(Message_entity_1.MessageEntity);
            yield messageRepository.delete({ message_id: (0, typeorm_1.In)(ids) });
        });
    }
}
exports.MessageService = MessageService;
