"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuestionManager = void 0;
class QuestionManager {
    constructor() {
        /**
         * The priority of the question manager.
         * @default 'command'
         */
        this.priority = 'command';
        /**
         * An object containing user IDs that are currently waiting for a response.
         * Each key is a user ID, and each value is a callback function.
         */
        this.waiting = {};
    }
    /**
     * Adds a new question for a specified user ID.
     * @param user_id - The ID of the user asking the question.
     * @param callback - The callback function that will handle the user's response.
     */
    addQuestion(user_id, callback) {
        this.waiting[user_id] = callback;
    }
    /**
     * Gets the callback function for a specified user ID and removes it from the waiting object.
     * If no callback function exists for the specified user ID, returns undefined.
     * @param user_id - The ID of the user whose callback function should be retrieved.
     * @param deleteQuestion - Optional flag that indicates if the question should be removed from the waiting object. Defaults to true.
     * @return The callback function associated with the user ID, or undefined if no such function exists.
     */
    getQuestion(user_id, deleteQuestion = true) {
        const question = this.waiting[user_id];
        if (!question)
            return undefined;
        if (deleteQuestion)
            delete this.waiting[user_id];
        return question;
    }
}
exports.QuestionManager = QuestionManager;
