import { Evogram } from '../Client';
import { BusinessConnectionContext, BusinessMessagesDeletedContext, CallbackQueryContext, ChatJoinRequestContext, ChosenInlineResultContext, InlineQueryContext, MessageContext, PollAnswerContext, PollContext, ServiceMessage, ShippingQueryContext } from '../migrated';
import { Polling } from '../transports';
import { TelegramChatBoostRemoved, TelegramChatBoostUpdated, TelegramChatMemberUpdated, TelegramMessageReactionCountUpdated, TelegramMessageReactionUpdated, TelegramPreCheckoutQuery, TelegramUpdateType } from '../types';
export type UpdateHandler<T> = (data: {
    context: T;
    client: Evogram;
}) => any;
export type UpdateHandlerMap = {
    [updateName in TelegramUpdateType]?: UpdateHandler<any>[];
};
export declare class Updates {
    private client;
    constructor(client: Evogram);
    handlers: UpdateHandlerMap;
    polling: Polling;
    /**
     * Method for registering update handlers
     * @param {TelegramUpdateType} update Name of the update to be processed
     * @param {TelegramUpdateType} handler Callback function, which will be called on a new update
     * @return {Updates} Return this
     *
     * @example
     * 	client.updates.on("message", message => {
     * 	    message.send("Hello, world!");
     * 	});
     */
    on(update: 'message' | 'edited_message' | 'channel_post' | 'edited_channel_post' | 'business_message' | 'edited_business_message', handler: UpdateHandler<MessageContext>): this;
    on(update: 'service_message', handler: UpdateHandler<ServiceMessage>): this;
    on(update: 'business_connection', handler: UpdateHandler<BusinessConnectionContext>): this;
    on(update: 'deleted_business_messages', handler: UpdateHandler<BusinessMessagesDeletedContext>): this;
    on(update: 'message_reaction', handler: UpdateHandler<TelegramMessageReactionUpdated>): this;
    on(update: 'message_reaction_count', handler: UpdateHandler<TelegramMessageReactionCountUpdated>): this;
    on(update: 'inline_query', handler: UpdateHandler<InlineQueryContext>): this;
    on(update: 'chosen_inline_result', handler: UpdateHandler<ChosenInlineResultContext>): this;
    on(update: 'callback_query', handler: UpdateHandler<CallbackQueryContext>): this;
    on(update: 'shipping_query', handler: UpdateHandler<ShippingQueryContext>): this;
    on(update: 'pre_checkout_query', handler: UpdateHandler<TelegramPreCheckoutQuery>): this;
    on(update: 'poll', handler: UpdateHandler<PollContext>): this;
    on(update: 'poll_answer', handler: UpdateHandler<PollAnswerContext>): this;
    on(update: 'my_chat_member' | 'chat_member', handler: UpdateHandler<TelegramChatMemberUpdated>): this;
    on(update: 'chat_join_request', handler: UpdateHandler<ChatJoinRequestContext>): this;
    on(update: 'chat_boost', handler: UpdateHandler<TelegramChatBoostUpdated>): this;
    on(update: 'removed_chat_boost', handler: UpdateHandler<TelegramChatBoostRemoved>): this;
}
