"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateUtil = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const js_yaml_1 = tslib_1.__importDefault(require("js-yaml"));
class TemplateUtil {
    static loadTemplates(path) {
        try {
            const fileContents = fs_1.default.readFileSync(path, 'utf8');
            const newTemplates = js_yaml_1.default.load(fileContents);
            this.templates = Object.assign(Object.assign({}, this.templates), newTemplates);
        }
        catch (error) {
            console.error('Error loading templates:', error);
        }
    }
    static getTemplate(path, params) {
        var _a, _b;
        const template = this.findNestedTemplate(path);
        if (!template)
            throw new Error(`Passed template "${path}" does not exist`);
        // Интерполируем весь объект
        let interpolatedTemplate = this.interpolateObject(template, params);
        if ((_a = interpolatedTemplate.reply_markup) === null || _a === void 0 ? void 0 : _a.inline_keyboard)
            interpolatedTemplate.reply_markup.inline_keyboard = (_b = interpolatedTemplate.reply_markup) === null || _b === void 0 ? void 0 : _b.inline_keyboard.map((x) => x.filter((x) => x.text)).filter((x) => x.length);
        return interpolatedTemplate;
    }
    static findNestedTemplate(path) {
        const keys = path.split('.');
        let current = this.templates;
        for (const key of keys) {
            if (current[key])
                current = current[key];
            else
                return undefined;
        }
        return typeof current === 'string' ? { text: current } : current;
    }
    static interpolate(template, params) {
        // Обработка тернарных выражений и переменных с использованием eval
        return template.replace(/{{\s*([\s\S]*?)\s*}}/g, (_, expression) => {
            try {
                // Создаем функцию, в которую передаем параметры для подстановки значений
                const func = new Function(...Object.keys(params || {}), `return ${expression};`);
                return func(...Object.values(params || {}));
            }
            catch (error) {
                console.error(`Error evaluating expression "${expression}":`, error);
                return '';
            }
        });
    }
    static interpolateObject(obj, params) {
        if (typeof obj === 'string') {
            // Интерполируем строки
            return this.interpolate(obj, params);
        }
        else if (Array.isArray(obj)) {
            // Для массивов применяем рекурсию для каждого элемента
            return obj.map((item) => this.interpolateObject(item, params));
        }
        else if (typeof obj === 'object' && obj !== null) {
            // Для объектов рекурсивно интерполируем каждое значение
            return Object.fromEntries(Object.entries(obj).map(([key, value]) => [key, this.interpolateObject(value, params)]));
        }
        // Если это не строка, массив или объект, возвращаем значение как есть
        return obj;
    }
}
exports.TemplateUtil = TemplateUtil;
TemplateUtil.templates = {};
