"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.arrayValidator = exports.parseArray = exports.ArrayValidatorError = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
var ArrayValidatorError;
(function (ArrayValidatorError) {
    ArrayValidatorError["VALUE_REQUIRED"] = "VALUE_REQUIRED";
    ArrayValidatorError["INVALID_ARRAY"] = "INVALID_ARRAY";
    ArrayValidatorError["TOO_FEW_ITEMS"] = "TOO_FEW_ITEMS";
    ArrayValidatorError["TOO_MANY_ITEMS"] = "TOO_MANY_ITEMS";
    ArrayValidatorError["INVALID_ITEM"] = "INVALID_ITEM";
})(ArrayValidatorError || (exports.ArrayValidatorError = ArrayValidatorError = {}));
const parseArray = (value, separator = /[,\s]+/) => {
    // Убираем лишние пробелы в начале и конце
    const cleanValue = value.trim();
    // Разбиваем строку на массив по разделителю
    return cleanValue
        .split(separator)
        .map((item) => item.trim())
        .filter((item) => item.length > 0);
};
exports.parseArray = parseArray;
const arrayValidator = (options = {}) => {
    return (context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const { value, context: cmdContext, arg } = context;
        // Если значение отсутствует и есть функция question
        if (!value && options.question) {
            yield options.question(cmdContext);
            return undefined;
        }
        if (!value) {
            if (!arg.isOptional)
                throw new errors_1.ValidatorError(options, ArrayValidatorError.VALUE_REQUIRED, `Array «${arg.name}» is required`);
            else
                return;
        }
        const array = (0, exports.parseArray)(value, options.separator);
        // Проверяем минимальную длину
        if (typeof options.minLength === 'number' && array.length < options.minLength) {
            throw new errors_1.ValidatorError(options, ArrayValidatorError.TOO_FEW_ITEMS, errors_1.ValidationErrors.get(ArrayValidatorError.TOO_FEW_ITEMS) ||
                `Array «${arg.name}» must contain at least ${options.minLength} items`);
        }
        // Проверяем максимальную длину
        if (typeof options.maxLength === 'number' && array.length > options.maxLength) {
            throw new errors_1.ValidatorError(options, ArrayValidatorError.TOO_MANY_ITEMS, errors_1.ValidationErrors.get(ArrayValidatorError.TOO_MANY_ITEMS) ||
                `Array «${arg.name}» must contain at most ${options.maxLength} items`);
        }
        // Если задан валидатор для элементов
        if (options.itemValidator) {
            const validatedItems = [];
            for (const item of array) {
                const validatedItem = yield options.itemValidator(Object.assign(Object.assign({}, context), { value: item }));
                if (validatedItem === undefined) {
                    yield ((_a = options.onError) === null || _a === void 0 ? void 0 : _a.call(options, options, ArrayValidatorError.INVALID_ITEM));
                    return undefined;
                }
                validatedItems.push(validatedItem);
            }
            return validatedItems;
        }
        return array;
    });
};
exports.arrayValidator = arrayValidator;
