"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.booleanValidator = exports.parseBoolean = exports.DEFAULT_FALSE_VALUES = exports.DEFAULT_TRUE_VALUES = exports.BooleanValidatorError = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
var BooleanValidatorError;
(function (BooleanValidatorError) {
    BooleanValidatorError["VALUE_REQUIRED"] = "VALUE_REQUIRED";
    BooleanValidatorError["INVALID_BOOLEAN"] = "INVALID_BOOLEAN";
})(BooleanValidatorError || (exports.BooleanValidatorError = BooleanValidatorError = {}));
exports.DEFAULT_TRUE_VALUES = ['true', 'yes', 'да', '1', 'on', 'включено', '+'];
exports.DEFAULT_FALSE_VALUES = ['false', 'no', 'нет', '0', 'off', 'выключено', '-'];
const parseBoolean = (value, trueValues = exports.DEFAULT_TRUE_VALUES, falseValues = exports.DEFAULT_FALSE_VALUES) => {
    const normalizedValue = value.toLowerCase().trim();
    if (trueValues.includes(normalizedValue)) {
        return true;
    }
    if (falseValues.includes(normalizedValue)) {
        return false;
    }
    return null;
};
exports.parseBoolean = parseBoolean;
const booleanValidator = (options = {}) => {
    return (context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const { value, context: cmdContext, arg } = context;
        if (!value && options.question) {
            yield options.question(cmdContext);
            return undefined;
        }
        if (!value) {
            if (!arg.isOptional)
                throw new errors_1.ValidatorError(options, BooleanValidatorError.VALUE_REQUIRED, errors_1.ValidationErrors.get(BooleanValidatorError.VALUE_REQUIRED) || `Boolean «${arg.name}» is required`);
            else
                return;
        }
        const parsedBoolean = (0, exports.parseBoolean)(value, options.trueValues, options.falseValues);
        if (parsedBoolean === null && !arg.isOptional) {
            throw new errors_1.ValidatorError(options, BooleanValidatorError.INVALID_BOOLEAN, errors_1.ValidationErrors.get(BooleanValidatorError.INVALID_BOOLEAN) || `Boolean «${arg.name}» is invalid`);
        }
        return parsedBoolean || undefined;
    });
};
exports.booleanValidator = booleanValidator;
