"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dateValidator = exports.parseDate = exports.DateValidatorError = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
var DateValidatorError;
(function (DateValidatorError) {
    DateValidatorError["VALUE_REQUIRED"] = "VALUE_REQUIRED";
    DateValidatorError["INVALID_DATE"] = "INVALID_DATE";
    DateValidatorError["DATE_TOO_EARLY"] = "DATE_TOO_EARLY";
    DateValidatorError["DATE_TOO_LATE"] = "DATE_TOO_LATE";
})(DateValidatorError || (exports.DateValidatorError = DateValidatorError = {}));
const parseDate = (value) => {
    // Убираем лишние пробелы
    const cleanValue = value.trim();
    try {
        // Пробуем разные форматы даты
        const formats = [
            // DD.MM.YYYY
            /^(\d{1,2})\.(\d{1,2})\.(\d{4})$/,
            // DD/MM/YYYY
            /^(\d{1,2})\/(\d{1,2})\/(\d{4})$/,
            // YYYY-MM-DD
            /^(\d{4})-(\d{1,2})-(\d{1,2})$/,
            // DD MM YYYY
            /^(\d{1,2})\s+(\d{1,2})\s+(\d{4})$/,
        ];
        for (const format of formats) {
            const match = cleanValue.match(format);
            if (match) {
                let [_, first, second, third] = match;
                // Для формата YYYY-MM-DD
                if (format === formats[2]) {
                    [_, third, second, first] = match;
                }
                const day = parseInt(first, 10);
                const month = parseInt(second, 10) - 1;
                const year = parseInt(third, 10);
                const date = new Date(year, month, day);
                // Проверяем валидность даты
                if (date.getDate() === day && date.getMonth() === month && date.getFullYear() === year) {
                    return date;
                }
            }
        }
        // Пробуем стандартный парсинг
        const date = new Date(cleanValue);
        if (!isNaN(date.getTime())) {
            return date;
        }
        return null;
    }
    catch (_a) {
        return null;
    }
};
exports.parseDate = parseDate;
const dateValidator = (options = {}) => {
    return (context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const { value, context: cmdContext, arg } = context;
        // Если значение отсутствует и есть функция question
        if (!value && options.question) {
            yield options.question(cmdContext);
            return undefined;
        }
        if (!value) {
            if (!arg.isOptional)
                throw new errors_1.ValidatorError(options, DateValidatorError.VALUE_REQUIRED, errors_1.ValidationErrors.get(DateValidatorError.VALUE_REQUIRED) || `Date «${arg.name}» is required`);
            else
                return;
        }
        const parsedDate = (0, exports.parseDate)(value);
        if (parsedDate === null) {
            throw new errors_1.ValidatorError(options, DateValidatorError.INVALID_DATE, errors_1.ValidationErrors.get(DateValidatorError.INVALID_DATE) || `Date «${arg.name}» is invalid`);
        }
        // Проверяем минимальную дату
        if (options.minDate && parsedDate < options.minDate) {
            throw new errors_1.ValidatorError(options, DateValidatorError.DATE_TOO_EARLY, errors_1.ValidationErrors.get(DateValidatorError.DATE_TOO_EARLY) || `Date «${arg.name}» is too early`);
        }
        // Проверяем максимальную дату
        if (options.maxDate && parsedDate > options.maxDate) {
            throw new errors_1.ValidatorError(options, DateValidatorError.DATE_TOO_LATE, errors_1.ValidationErrors.get(DateValidatorError.DATE_TOO_LATE) || `Date «${arg.name}» is too late`);
        }
        return parsedDate || undefined;
    });
};
exports.dateValidator = dateValidator;
