"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.percentValidator = exports.parsePercent = exports.PercentValidatorError = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
var PercentValidatorError;
(function (PercentValidatorError) {
    PercentValidatorError["VALUE_REQUIRED"] = "VALUE_REQUIRED";
    PercentValidatorError["INVALID_PERCENT"] = "INVALID_PERCENT";
    PercentValidatorError["LESS_THAN_MIN"] = "LESS_THAN_MIN";
    PercentValidatorError["GREATER_THAN_MAX"] = "GREATER_THAN_MAX";
})(PercentValidatorError || (exports.PercentValidatorError = PercentValidatorError = {}));
const parsePercent = (value, allowDecimal = true) => {
    // Убираем все пробелы и знак процента
    const cleanValue = value.replace(/\s+|%/g, '');
    try {
        const number = allowDecimal ? parseFloat(cleanValue) : parseInt(cleanValue);
        return isNaN(number) ? null : number;
    }
    catch (_a) {
        return null;
    }
};
exports.parsePercent = parsePercent;
const percentValidator = (options = {}) => {
    return (context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        var _a, _b;
        const { value, context: cmdContext, arg } = context;
        if (typeof value === 'number')
            return value;
        if (!value && options.question) {
            yield options.question(cmdContext);
            return undefined;
        }
        if (!value) {
            if (!arg.isOptional)
                throw new errors_1.ValidatorError(options, PercentValidatorError.VALUE_REQUIRED, errors_1.ValidationErrors.get(PercentValidatorError.VALUE_REQUIRED) || `Percent «${arg.name}» is required`);
            else
                return;
        }
        const parsedPercent = (0, exports.parsePercent)(value, options.allowDecimal);
        if (parsedPercent === null) {
            throw new errors_1.ValidatorError(options, PercentValidatorError.INVALID_PERCENT, errors_1.ValidationErrors.get(PercentValidatorError.INVALID_PERCENT) || `Percent «${arg.name}» is invalid`);
        }
        const min = (_a = options.min) !== null && _a !== void 0 ? _a : 0;
        const max = (_b = options.max) !== null && _b !== void 0 ? _b : 100;
        if (parsedPercent < min) {
            throw new errors_1.ValidatorError(options, PercentValidatorError.LESS_THAN_MIN, errors_1.ValidationErrors.get(PercentValidatorError.LESS_THAN_MIN) || `Percent «${arg.name}» is less than ${min}`);
        }
        if (parsedPercent > max) {
            throw new errors_1.ValidatorError(options, PercentValidatorError.GREATER_THAN_MAX, errors_1.ValidationErrors.get(PercentValidatorError.GREATER_THAN_MAX) || `Percent «${arg.name}» is greater than ${max}`);
        }
        return parsedPercent;
    });
};
exports.percentValidator = percentValidator;
