"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringValidator = exports.StringValidatorError = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("./errors");
var StringValidatorError;
(function (StringValidatorError) {
    StringValidatorError["VALUE_REQUIRED"] = "VALUE_REQUIRED";
    StringValidatorError["TOO_SHORT"] = "TOO_SHORT";
    StringValidatorError["TOO_LONG"] = "TOO_LONG";
    StringValidatorError["INVALID_FORMAT"] = "INVALID_FORMAT";
})(StringValidatorError || (exports.StringValidatorError = StringValidatorError = {}));
const stringValidator = (options = {}) => {
    return (context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const { value, context: cmdContext, arg } = context;
        // Если значение отсутствует и есть функция question
        if (!value && options.question) {
            yield options.question(cmdContext);
            return undefined;
        }
        if (!value) {
            if (!arg.isOptional)
                throw new errors_1.ValidatorError(options, StringValidatorError.VALUE_REQUIRED, errors_1.ValidationErrors.get(StringValidatorError.VALUE_REQUIRED) || `String «${arg.name}» is required`);
            else
                return;
        }
        const stringValue = value.trim();
        // Проверяем минимальную длину
        if (typeof options.minLength === 'number' && stringValue.length < options.minLength) {
            throw new errors_1.ValidatorError(options, StringValidatorError.TOO_SHORT, errors_1.ValidationErrors.get(StringValidatorError.TOO_SHORT) || `String «${arg.name}» is too short`);
        }
        // Проверяем максимальную длину
        if (typeof options.maxLength === 'number' && stringValue.length > options.maxLength) {
            throw new errors_1.ValidatorError(options, StringValidatorError.TOO_LONG, errors_1.ValidationErrors.get(StringValidatorError.TOO_LONG) || `String «${arg.name}» is too long`);
        }
        // Проверяем соответствие паттерну, если он задан
        if (options.pattern && !options.pattern.test(stringValue)) {
            throw new errors_1.ValidatorError(options, StringValidatorError.INVALID_FORMAT, errors_1.ValidationErrors.get(StringValidatorError.INVALID_FORMAT) || `String «${arg.name}» is invalid`);
        }
        return stringValue;
    });
};
exports.stringValidator = stringValidator;
